Crate atlas_builtins_default_costs

Crate atlas_builtins_default_costs 

Modules

atlas_feature_set
Atlas feature set
atlas_program_ids
Atlas program IDs

Structs

MigratingBuiltinCost

Enums

BuiltinCost
BuiltinMigrationFeatureIndex

Constants

MIGRATING_BUILTINS_COSTS

Statics

MAYBE_BUILTIN_KEY
A table of 256 booleans indicates whether the first u8 of a Pubkey exists in BUILTIN_INSTRUCTION_COSTS. If the value is true, the Pubkey might be a builtin key; if false, it cannot be a builtin key. This table allows for quick filtering of builtin program IDs without the need for hashing.

Functions

get_builtin_migration_feature_index
get_migration_feature_id
Helper function to return ref of migration feature Pubkey at position index from MIGRATING_BUILTINS_COSTS

Type Aliases

Pubkey
Atlas public key type