Modules
- atlas_
feature_ set - Atlas feature set
- atlas_
program_ ids - Atlas program IDs
Structs
Enums
Constants
Statics
- MAYBE_
BUILTIN_ KEY - A table of 256 booleans indicates whether the first
u8of a Pubkey exists in BUILTIN_INSTRUCTION_COSTS. If the value is true, the Pubkey might be a builtin key; if false, it cannot be a builtin key. This table allows for quick filtering of builtin program IDs without the need for hashing.
Functions
- get_
builtin_ migration_ feature_ index - get_
migration_ feature_ id - Helper function to return ref of migration feature Pubkey at position
indexfrom MIGRATING_BUILTINS_COSTS
Type Aliases
- Pubkey
- Atlas public key type